@@ -50,9 +50,6 @@ object_name = _('Mail domain')
 object_name_plural = _('Mail domains')
 long_description = ''
 
-module_search_filter = univention.admin.filter.conjunction('&', [
-	univention.admin.filter.expression('objectClass', 'univentionMailDomainname'),
-])
 options = {
 	'default': univention.admin.option(
 		short_description=short_description,
@@ -99,4 +96,5 @@ class object(univention.admin.handlers.simpleLdap):
 
 
 lookup = object.lookup
+lookup_filter = object.lookup_filter
 identify = object.identify
